{% include "admin/feincms/load-jquery.include" %}

<div id="{{ identifier }}-new">
    {{ content|safe }}
</div>

<script type="text/javascript">
opener.feincms.fe_update_content('{{ identifier }}', feincms.jQuery('#{{ identifier }}-new').html());

window.close();
</script>
